@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.49 2003/06/16 20:32:41 dcransto Exp $ */
+/* $Id: gdict-applet.c,v 1.55 2004/02/23 06:49:41 dsmit Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -56,19 +56,24 @@ button_press_hack (GtkWidget *w, GdkEventButton *event, gpointer data)
 static void
 entry_activate_cb (GtkEntry *entry, gpointer data)
 {
-    	gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+	GDictApplet *applet = data;
+
+	gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
     
     	if (!context)
 		gdict_init_context ();
     	if (!GTK_WIDGET_VISIBLE (gdict_app))
         	gtk_widget_show (gdict_app);
-    
+   
+	gtk_window_set_screen (GTK_WINDOW (gdict_app),
+			       gtk_widget_get_screen (applet->applet_widget));
+	
     	gtk_window_present (GTK_WINDOW (gdict_app));
     
     	if (!text || *text == 0)
         	return;
         
-    	g_strdown (text);
+    	g_utf8_strdown (text, strlen (text));
 	gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
     	gdict_app_do_lookup (text);
     	g_free (text);
@@ -114,11 +119,14 @@ setup_applet_widgets (GDictApplet *applet)
     	};
 	
 	gboolean use_horizontal = TRUE;
-	
+
+
+	applet->about_dialog = NULL;
+
 	if (applet->box) {
 		gtk_widget_destroy (applet->box);
 	}
-		
+
 	if ((applet->orient == PANEL_APPLET_ORIENT_LEFT || applet->orient == PANEL_APPLET_ORIENT_RIGHT) || 
 	    ((applet->orient == PANEL_APPLET_ORIENT_UP || applet->orient == PANEL_APPLET_ORIENT_DOWN) && applet->panel_size >= 48)) {
 		use_horizontal = FALSE;
@@ -223,6 +231,20 @@ send_button_to_entry_event (GtkWidget *widget, GdkEventButton *event, GDictApple
 	return FALSE;
 }
 
+static gboolean
+destroy_applet (GtkWidget *widget, gpointer data)
+{
+	GDictApplet *applet = data;
+
+	if (applet->about_dialog)
+		gtk_widget_destroy (applet->about_dialog);
+
+	gtk_widget_destroy (applet->button_widget);
+	gtk_widget_destroy (applet->box);
+	gtk_widget_destroy (applet->entry_widget);
+	gtk_widget_destroy (applet->applet_widget);
+}
+
 static void 
 menu_event_cb (BonoboUIComponent            *comp,
                const gchar                  *path,
@@ -261,7 +283,7 @@ text_received (GtkClipboard *clipboard, const gchar *text, gpointer data)
 	
 	if (*lookup_text == 0)
         	return;
-    	g_strdown (lookup_text);
+    	g_utf8_strdown (lookup_text, strlen(lookup_text));
     	gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), text);
     	entry_activate_cb (GTK_ENTRY (applet->entry_widget), applet);
 #if 0    	
@@ -288,7 +310,25 @@ about_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-	gdict_about(NULL);
+	GDictApplet *applet = user_data;
+
+	if (applet->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+				       gtk_widget_get_screen (applet->applet_widget));
+
+		gtk_window_present (GTK_WINDOW (applet->about_dialog));
+		return;
+	}
+
+	applet->about_dialog = gdict_about_new ();
+
+	gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+			       gtk_widget_get_screen (applet->applet_widget));
+
+	g_signal_connect (G_OBJECT (applet->about_dialog), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &applet->about_dialog);
+
+	gtk_widget_show (applet->about_dialog);
 }
 
 static void
@@ -327,6 +367,7 @@ prefs_cb (BonoboUIComponent *uic,
 {
 	if (!context)
 		gdict_init_context ();
+
 	gdict_app_show_preferences ();
 }
 
@@ -344,6 +385,7 @@ gdict_applet_new (PanelApplet *parent_applet)
 {
 	GDictApplet *applet;
 	BonoboUIComponent *component;
+	GtkIconInfo *icon_info;
  	
  	applet = g_new0 (GDictApplet, 1);
  	
@@ -351,7 +393,11 @@ gdict_applet_new (PanelApplet *parent_applet)
 	applet->panel_size = panel_applet_get_size (PANEL_APPLET (applet->applet_widget));
  	applet->orient = panel_applet_get_orient (PANEL_APPLET (applet->applet_widget));
 	
- 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
+	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "gdict", 48, 0);
+	if (icon_info) {
+		gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+	}
  	
 	panel_applet_set_flags (parent_applet, PANEL_APPLET_EXPAND_MINOR);
 
@@ -368,6 +414,17 @@ gdict_applet_new (PanelApplet *parent_applet)
                             		   gdict_applet_menu_verbs,
                             		   applet);                               
 
+	if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/prefs",
+					      "hidden", "1",
+					      NULL);
+	}
+
  	/* server will be contacted when an action is performed */
  	context = NULL;
 	
@@ -382,7 +439,9 @@ gdict_applet_new (PanelApplet *parent_applet)
 			  G_CALLBACK (send_button_to_entry_event), applet); 
  	g_signal_connect (G_OBJECT (applet->applet_widget), "button_press_event",                         
 			  G_CALLBACK (set_show_dictionary_menu_state), NULL);
- 	
+	g_signal_connect (G_OBJECT (applet->applet_widget), "destroy",
+			  G_CALLBACK (destroy_applet), applet);
+
 	return TRUE;
 }
 
